/*
 *  inf.h
 *  mod_musicindex
 *
 *  $Id: sort.h 873 2009-09-08 13:31:34Z varenet $
 *
 *  Created by Thibaut VARENE on Thu Mar 20 2003.
 *  Copyright (c) 2003-2004 Regis BOUDIN
 *  Copyright (c) 2003-2004 Thibaut VARENE
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License version 2.1,
 *  as published by the Free Software Foundation.
 *
 */

#ifndef SORT_H
#define SORT_H

#include "mod_musicindex.h"

#define listsort sort_mergesort
void listsort(mu_pack *const, const unsigned char *const);

#endif	/* SORT_H */
